@@ -1,7 +1,7 @@
 package Perinci::CmdLine::Base;
 
-our $DATE = '2015-04-25'; # DATE
-our $VERSION = '1.12'; # VERSION
+our $DATE = '2015-05-06'; # DATE
+our $VERSION = '1.13'; # VERSION
 
 use 5.010001;
 use strict;
@@ -1252,7 +1252,7 @@ sub run {
 }
 
 1;
-# ABSTRACT: Base class for Perinci::CmdLine{Classic,::Lite}
+# ABSTRACT: Base class for Perinci::CmdLine{::Classic,::Lite}
 
 __END__
 
@@ -1262,11 +1262,11 @@ __END__
 
 =head1 NAME
 
-Perinci::CmdLine::Base - Base class for Perinci::CmdLine{Classic,::Lite}
+Perinci::CmdLine::Base - Base class for Perinci::CmdLine{::Classic,::Lite}
 
 =head1 VERSION
 
-This document describes version 1.12 of Perinci::CmdLine::Base (from Perl distribution Perinci-CmdLine-Lite), released on 2015-04-25.
+This document describes version 1.13 of Perinci::CmdLine::Base (from Perl distribution Perinci-CmdLine-Lite), released on 2015-05-06.
 
 =head1 DESCRIPTION
 
@@ -1281,8 +1281,8 @@ If you execute C<run()>, this is what will happen, in order:
 =item * Detect if we are running under tab completion mode
 
 This is done by checking the existence of special environment varibles like
-C<COMP_LINE> or C<COMMAND_LINE> (tcsh). If yes, then jump to L</"PROGRAM FLOW
-(TAB COMPLETION)">. Otherwise, continue.
+C<COMP_LINE> (bash) or C<COMMAND_LINE> (tcsh). If yes, then jump to L</"PROGRAM
+FLOW (TAB COMPLETION)">. Otherwise, continue.
 
 =item * Run hook_before_run, if defined
 
@@ -1294,7 +1294,7 @@ Some ideas that you can do in this hook: XXX.
 =item * Parse command-line arguments (@ARGV) and set C<action>
 
 If C<read_env> attribute is set to true, and there is environment variable
-defined to set default options (see documentation on L<read_env> and C<env_name>
+defined to set default options (see documentation on C<read_env> and C<env_name>
 attributes) then the environment variable is parsed and prepended first to the
 command-line, so it can be parsed together. For example, if your program is
 called C<foo> and environment variable C<FOO_OPT> is set to C<--opt1 --opt2
@@ -1302,9 +1302,9 @@ val>. When you execute:
 
  % foo --no-opt1 --trace 1 2
 
-then C<@ARGV> will be set to C<<('--opt1', '--opt2', 'val', '--no-opt1',
-'--trace', 1, 2)>>. This way, command-line arguments can have a higher
-precedence and override setting from the environment variable (in the example,
+then C<@ARGV> will be set to C<< ('--opt1', '--opt2', 'val', '--no-opt1',
+'--trace', 1, 2) >>. This way, command-line arguments can have a higher
+precedence and override settings from the environment variable (in this example,
 C<--opt1> is negated by C<--no-opt1>).
 
 Currently, parsing is done in two steps. The first step is to extract subcommand
@@ -1319,7 +1319,7 @@ specified).
 In the first step, since we do not know the subcommand yet, we only parse common
 options and strip them. Unknown options at this time will be passed through.
 
-If user specifies common option like C<--help> or <--version>, then action will
+If user specifies common option like C<--help> or C<--version>, then action will
 be set to (respectively) C<help> and C<version> and the second step will be
 skipped. Otherwise we continue the the second step and action by default is set
 to C<call>.
@@ -2145,7 +2145,7 @@ Please visit the project's homepage at L<https://metacpan.org/release/Perinci-Cm
 
 =head1 SOURCE
 
-Source repository is at L<https://github.com/sharyanto/perl-Perinci-CmdLine-Lite>.
+Source repository is at L<https://github.com/perlancar/perl-Perinci-CmdLine-Lite>.
 
 =head1 BUGS
 
