@@ -1,7 +1,7 @@
 package Perinci::CmdLine::Lite;
 
-our $DATE = '2015-04-25'; # DATE
-our $VERSION = '1.12'; # VERSION
+our $DATE = '2015-05-06'; # DATE
+our $VERSION = '1.13'; # VERSION
 
 use 5.010001;
 # use strict; # already enabled by Mo
@@ -222,6 +222,26 @@ sub hook_before_action {
                 die [400, "Argument '$arg' fails validation: $res"];
             }
         }
+
+        if ($meta->{args_rels}) {
+            my $schema = [hash => $meta->{args_rels}];
+            my $sah = Data::Sah->new;
+            my $hc  = $sah->get_compiler("human");
+            my $cd  = $hc->init_cd;
+            $cd->{args}{lang} //= $cd->{default_lang};
+            my $v = Data::Sah::gen_validator($schema, {
+                return_type => 'str',
+                human_hash_values => {
+                    field  => $hc->_xlt($cd, "argument"),
+                    fields => $hc->_xlt($cd, "arguments"),
+                },
+            });
+            my $res = $v->($r->{args});
+            if ($res) {
+                die [400, $res];
+            }
+        }
+
     }
 }
 
@@ -546,7 +566,7 @@ Perinci::CmdLine::Lite - A lightweight Rinci/Riap-based command-line application
 
 =head1 VERSION
 
-This document describes version 1.12 of Perinci::CmdLine::Lite (from Perl distribution Perinci-CmdLine-Lite), released on 2015-04-25.
+This document describes version 1.13 of Perinci::CmdLine::Lite (from Perl distribution Perinci-CmdLine-Lite), released on 2015-05-06.
 
 =head1 SYNOPSIS
 
@@ -758,7 +778,7 @@ Please visit the project's homepage at L<https://metacpan.org/release/Perinci-Cm
 
 =head1 SOURCE
 
-Source repository is at L<https://github.com/sharyanto/perl-Perinci-CmdLine-Lite>.
+Source repository is at L<https://github.com/perlancar/perl-Perinci-CmdLine-Lite>.
 
 =head1 BUGS
 
